@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011, 2014 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011, 2014-2015 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
 use strict;
@@ -19,7 +19,7 @@ our $MIN_ABBREV = length('tr');
 our $HELP   = <<"HELP";
 =pod
 
-B<show trace> [I<show trace subcommands>]
+B<set trace> [I<set trace subcommands>]
 
 Set tracing of various sorts.
 
@@ -41,16 +41,14 @@ our $SHORT_HELP   = "Set tracing of various sorts.";
 
 unless (caller) {
     # Demo it.
-    require Devel::Trepan;
-    # require_relative '../../mock'
-    # dbgr, parent_cmd = MockDebugger::setup('set', false)
-    # cmd              = Trepan::SubSubcommand::SetMax.new(dbgr.core.processor,
-    #                                                      parent_cmd)
-    # cmd.run(cmd.prefix + ['string', '30'])
-
-    # %w(s lis foo).each do |prefix|
-    #   p [prefix, cmd.complete(prefix)]
-    # end
+    # FIXME: DRY with other subcommand manager demo code.
+    require Devel::Trepan::CmdProcessor::Mock;
+    my ($proc, $cmd) =
+	Devel::Trepan::CmdProcessor::Mock::subcmd_setup();
+    Devel::Trepan::CmdProcessor::Mock::subcmd_demo_info($proc, $cmd);
+    $cmd->run($cmd->{prefix});
+    my @args = (@{$cmd->{prefix}}, 'print', 'off');
+    $cmd->run(\@args);
 }
 
 1;
